==> gbsite-1.1.0.tar.gz: gbsite/scripts/project/bugs/buglist.php <==
<?

/**************************************************
Program name:		buglist.php  
Author:			Allen McGrath (allen@greatbridge.com)

Description:		Displays all bugs of a particular
			project so the admin can update them.
			
Create Date:		10/9/00 

Modified Date(s):
    Chris Ryan <chris@greatbridge.com> 11/20/2000
        - Modified query to do search sort options
							 
**************************************************/
 
$web_page = "buglistpage";
include("site_info.php");
$group_group_id = "buglist";

$do_debug = "no";

$sort_option = "DATE_CREATED DESC";
$select_options = "";

     if($sortby == "date") $sort_option = "DATE_CREATED";
else if($sortby == "datedesc") $sort_option = "DATE_CREATED DESC";
$t = $showtype;
unset($showtype);
while(list(,$tid) = @each($t)) {
    if(!empty($tid)) $showtype[] = $tid;
}
if(empty($showalltypes)) {
    if(!empty($showtype)) {
        $select_options = " AND ( ";
        while(list($id,$tid) = @each($showtype)) {
            if($id > 0) $select_options .= " OR";
            $select_options .= " B.CAT_ID = $tid ";
        }
        $select_options .= " ) ";
    }
}

$bg_query = "  SELECT A.BUG_ID, A.TASK_ID, A.TITLE, A.DESCRIPTION, ".
            "         A.DATE_CREATED,B.CAT_NAME,C.CAT_NAME as SEVERITY " .
            "    FROM BUG A, CATEGORY B, CATEGORY C " .
            "   WHERE A.PROJECT_ID = $project_id " .
            "     AND B.CAT_ID = A.STATUS_ID " . 
            "     AND C.CAT_ID  = A.SEVERITY_ID ".
            $select_options .
            "ORDER BY $sort_option ";
						
$bg_result = pg_exec($conn,$bg_query);


if ($do_debug == "yes") {
echo "<li>" . $bg_query;
echo "<li>" . pg_numrows($bg_result);
}

$statusList = getBugStatusList();

$r = 0;
while ($row = @pg_fetch_array($bg_result,$r++)) {
	$bug_list[] = array( "bug_id"       => $row["bug_id"],
                             "title"        => $row["title"],
                             "description"  => $row["description"],
                             "cat_name"     => $row["cat_name"],
                             "severity"     => $row["severity"],
                             "task_id"      => $row["task_id"],
                             "date_created" => $row["date_created"]);
}

$num_bugs = count($bug_list);

include($page_template);

?>

==> gbsite-1.1.1.tar.gz: gbsite/scripts/project/bugs/buglist.php <==
<?

/**************************************************
Program name:		buglist.php  
Author:			Allen McGrath (allen@greatbridge.com)

Description:		Displays all bugs of a particular
			project so the admin can update them.
			
Create Date:		10/9/00 

Modified Date(s):
    Chris Ryan <chris@greatbridge.com> 11/20/2000
        - Modified query to do search sort options
							 
**************************************************/
 
$web_page = "buglistpage";
include("site_info.php");
$group_group_id = "buglist";

$do_debug = "no";

$sort_option = "DATE_CREATED DESC";
$select_options = "";

     if($sortby == "date") $sort_option = "DATE_CREATED";
else if($sortby == "datedesc") $sort_option = "DATE_CREATED DESC";
$t = $showtype;
unset($showtype);
while(list(,$tid) = @each($t)) {
    if(!empty($tid)) $showtype[] = $tid;
}
if(empty($showalltypes)) {
    if(!empty($showtype)) {
        $select_options = " AND ( ";
        while(list($id,$tid) = @each($showtype)) {
            if($id > 0) $select_options .= " OR";
            if($tid == "!Closed")
                $select_options .= " B.CAT_ID != 50 ";
            else 
                $select_options .= " B.CAT_ID = $tid ";
        }
        $select_options .= " ) ";
    }
}

$bg_query = "  SELECT A.BUG_ID, A.TASK_ID, A.TITLE, A.DESCRIPTION, ".
            "         A.DATE_CREATED,B.CAT_NAME,C.CAT_NAME as SEVERITY, " .
            "         (select count(*) from bug_comment bc where bc.bug_id = A.BUG_ID) AS COMMENT_COUNT ".
            "    FROM BUG A, CATEGORY B, CATEGORY C " .
            "   WHERE A.PROJECT_ID = $project_id " .
            "     AND B.CAT_ID = A.STATUS_ID " . 
            "     AND C.CAT_ID  = A.SEVERITY_ID ".
            $select_options .
            "ORDER BY $sort_option ";
						
$bg_result = pg_exec($conn,$bg_query);


if ($do_debug == "yes") {
echo "<li>" . $bg_query;
echo "<li>" . pg_numrows($bg_result);
}

$statusList = getBugStatusList();

$r = 0;
while ($row = @pg_fetch_array($bg_result,$r++)) {
	$bug_list[] = array( "bug_id"        => $row["bug_id"],
                             "title"         => $row["title"],
                             "description"   => $row["description"],
                             "cat_name"      => $row["cat_name"],
                             "severity"      => $row["severity"],
                             "task_id"       => $row["task_id"],
                             "date_created"  => $row["date_created"],
                             "comment_count" => $row["comment_count"]);
}

$num_bugs = count($bug_list);

include($page_template);

?>
